@@ -211,6 +211,14 @@ pub fn impl_table_trait(ast: &DeriveInput) -> TokenStream {
         format!("{}_{}", name_str, "callback_context").as_str(),
         name.span(),
     );
+    let scrollbar = Ident::new(
+        format!("{}_{}", name_str, "scrollbar").as_str(),
+        name.span(),
+    );
+    let hscrollbar = Ident::new(
+        format!("{}_{}", name_str, "hscrollbar").as_str(),
+        name.span(),
+    );
 
     let gen = quote! {
         unsafe impl TableExt for #name {
@@ -634,6 +642,24 @@ pub fn impl_table_trait(ast: &DeriveInput) -> TokenStream {
                     mem::transmute(#callback_context(self.inner))
                 }
             }
+
+            fn scrollbar(&self) -> crate::valuator::Scrollbar {
+                assert!(!self.was_deleted());
+                unsafe {
+                  let ptr = #scrollbar(self.inner);
+                  assert!(!ptr.is_null());
+                  crate::valuator::Scrollbar::from_widget_ptr(ptr as *mut fltk_sys::widget::Fl_Widget)
+                }
+            }
+
+            fn hscrollbar(&self) -> crate::valuator::Scrollbar {
+                assert!(!self.was_deleted());
+                unsafe {
+                  let ptr = #hscrollbar(self.inner);
+                  assert!(!ptr.is_null());
+                  crate::valuator::Scrollbar::from_widget_ptr(ptr as *mut fltk_sys::widget::Fl_Widget)
+                }
+            }
         }
     };
     gen.into()
